==> webStore_2.8.7_estable.zip: comunes/procesos_seccion/pedidos_ptes.php <==
<?php
	
	//---------------------------------------------------------------------------------------------------------
	// 23/Julio/2015
	// Versión 1.0 Recogemos los datos que utilizaremos en el orden y filtrado de las pedidos_ptes
	//---------------------------------------------------------------------------------------------------------
	
	
	
	include('comunes/globals.php');
	
	//El funcionamiento es sencillo, miramos si alguna de las variables está activa en las cookies. En caso afirmativo las metemos en la sesión, limpiamos esas cookies
	//y recargamos la página
	
	//---------------------------------------------------------------------------------------------------------
	//Filtrados
	//---------------------------------------------------------------------------------------------------------
	$fecha_inicio_pedidos_ptes = Sesion::getCookieValue('fecha_inicio');
	$fecha_fin_pedidos_ptes = Sesion::getCookieValue('fecha_fin');
	$solo_libros_pedidos_ptes = Sesion::getCookieValue('solo_libros');
	$solo_papeleria_pedidos_ptes = Sesion::getCookieValue('solo_papeleria');
	
    $recargar_web = $recargar_web | false;
	//Si nos han pasado fecha de inicio la metemos en la sesión
	if ($fecha_inicio_pedidos_ptes != NULL){
		Sesion::set('fecha_inicio_pedidos_ptes', $fecha_inicio_pedidos_ptes);
		borrarCookie('fecha_inicio');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}
	
	//Si nos han pasado fecha de fin, la metemos en la sesión
	if ($fecha_fin_pedidos_ptes != NULL){
		Sesion::set('fecha_fin_pedidos_ptes', $fecha_fin_pedidos_ptes);
		borrarCookie('fecha_fin');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}

	//Si nos han pasado la opción de 'solo libros' la miramos en la sesión
	if ($solo_libros_pedidos_ptes !== NULL){
		Sesion::set('solo_libros_pedidos_ptes', $solo_libros_pedidos_ptes);
		borrarCookie('solo_libros');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}

	//Si nos han pasado la opción de 'solo libros' la miramos en la sesión
	if ($solo_papeleria_pedidos_ptes !== NULL){
		Sesion::set('solo_papeleria_pedidos_ptes', $solo_papeleria_pedidos_ptes);
		borrarCookie('solo_papeleria');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}

	//---------------------------------------------------------------------------------------------------------
	//Orden
	//---------------------------------------------------------------------------------------------------------
	$orden_pedidos_ptes = Sesion::getCookieValue('orden');
	$tipo_orden_pedidos_ptes = Sesion::getCookieValue('tipo_orden');


	//Controlamos si nos han pasado un orden
	if ($orden_pedidos_ptes != NULL){
		Sesion::set('orden_pedidos_ptes', $orden_pedidos_ptes);
		borrarCookie('orden');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}
	//Hay que controlar el tipo de orden (ascendente o descendente)
	if ($tipo_orden_pedidos_ptes != NULL){
		Sesion::set('tipo_orden_pedidos_ptes', $tipo_orden_pedidos_ptes);
		borrarCookie('tipo_orden');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}
	
	//---------------------------------------------------------------------------------------------------------
	//Limpiamos las cookies
	//---------------------------------------------------------------------------------------------------------
	$limpiar_filtrado= Sesion::getCookieValue('limpiar_filtrado');
	if ($limpiar_filtrado != NULL){
		Sesion::set('fecha_inicio_pedidos_ptes', '');
		Sesion::set('fecha_fin_pedidos_ptes', '');
		Sesion::set('solo_libros_pedidos_ptes', '');
		Sesion::set('solo_papeleria_pedidos_ptes', '');
		borrarCookie('limpiar_filtrado');
        Sesion::setReloadPage(Sesion::getReloadPage() | true)
	}
?>

==> webStore_2.8.9.003_estable.zip: comunes/procesos_seccion/pedidos_ptes.php <==
<?php
	
	//---------------------------------------------------------------------------------------------------------
	// 23/Julio/2015
	// Versión 1.0 Recogemos los datos que utilizaremos en el orden y filtrado de las pedidos_ptes
	//---------------------------------------------------------------------------------------------------------
	
	
	
	include('comunes/globals.php');
	
	//El funcionamiento es sencillo, miramos si alguna de las variables está activa en las cookies. En caso afirmativo las metemos en la sesión, limpiamos esas cookies
	//y recargamos la página
	
	//---------------------------------------------------------------------------------------------------------
	//Filtrados
	//---------------------------------------------------------------------------------------------------------
	$fecha_inicio_pedidos_ptes = Sesion::getCookieValue('fecha_inicio');
	$fecha_fin_pedidos_ptes = Sesion::getCookieValue('fecha_fin');
	$solo_libros_pedidos_ptes = Sesion::getCookieValue('solo_libros');
	$solo_papeleria_pedidos_ptes = Sesion::getCookieValue('solo_papeleria');
	
    $recargar_web = $recargar_web | false;
	//Si nos han pasado fecha de inicio la metemos en la sesión
	if ($fecha_inicio_pedidos_ptes != NULL){
		Sesion::set('fecha_inicio_pedidos_ptes', $fecha_inicio_pedidos_ptes);
		borrarCookie('fecha_inicio');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}
	
	//Si nos han pasado fecha de fin, la metemos en la sesión
	if ($fecha_fin_pedidos_ptes != NULL){
		Sesion::set('fecha_fin_pedidos_ptes', $fecha_fin_pedidos_ptes);
		borrarCookie('fecha_fin');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}

	//Si nos han pasado la opción de 'solo libros' la miramos en la sesión
	if ($solo_libros_pedidos_ptes !== NULL){
		Sesion::set('solo_libros_pedidos_ptes', $solo_libros_pedidos_ptes);
		borrarCookie('solo_libros');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}

	//Si nos han pasado la opción de 'solo libros' la miramos en la sesión
	if ($solo_papeleria_pedidos_ptes !== NULL){
		Sesion::set('solo_papeleria_pedidos_ptes', $solo_papeleria_pedidos_ptes);
		borrarCookie('solo_papeleria');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}

	//---------------------------------------------------------------------------------------------------------
	//Orden
	//---------------------------------------------------------------------------------------------------------
	$orden_pedidos_ptes = Sesion::getCookieValue('orden');
	$tipo_orden_pedidos_ptes = Sesion::getCookieValue('tipo_orden');


	//Controlamos si nos han pasado un orden
	if ($orden_pedidos_ptes != NULL){
		Sesion::set('orden_pedidos_ptes', $orden_pedidos_ptes);
		borrarCookie('orden');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}
	//Hay que controlar el tipo de orden (ascendente o descendente)
	if ($tipo_orden_pedidos_ptes != NULL){
		Sesion::set('tipo_orden_pedidos_ptes', $tipo_orden_pedidos_ptes);
		borrarCookie('tipo_orden');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}
	
	//---------------------------------------------------------------------------------------------------------
	//Limpiamos las cookies
	//---------------------------------------------------------------------------------------------------------
	$limpiar_filtrado= Sesion::getCookieValue('limpiar_filtrado');
	if ($limpiar_filtrado != NULL){
		Sesion::set('fecha_inicio_pedidos_ptes', '');
		Sesion::set('fecha_fin_pedidos_ptes', '');
		Sesion::set('solo_libros_pedidos_ptes', '');
		Sesion::set('solo_papeleria_pedidos_ptes', '');
		borrarCookie('limpiar_filtrado');
        Sesion::setReloadPage(Sesion::getReloadPage() | true);
	}
?>
